@@ -11,14 +11,14 @@
 #include "databaseinterface.h"
 #include "trackslistener.h"
 
-#include <QHash>
 #include <QString>
 #include <QUrl>
-#include <QVector>
+#include <QList>
 
 #include <QStringListModel>
 
-#include <QtTest>
+#include <QSignalSpy>
+#include <QTest>
 
 ManageMediaPlayerControlTest::ManageMediaPlayerControlTest(QObject *parent) : QObject(parent)
 {
@@ -28,7 +28,7 @@ ManageMediaPlayerControlTest::ManageMediaPlayerControlTest(QObject *parent) : QO
 void ManageMediaPlayerControlTest::initTestCase()
 {
     qRegisterMetaType<QHash<QString,QUrl>>("QHash<QString,QUrl>");
-    qRegisterMetaType<QVector<qlonglong>>("QVector<qlonglong>");
+    qRegisterMetaType<QList<qlonglong>>("QList<qlonglong>");
     qRegisterMetaType<QHash<qlonglong,int>>("QHash<qlonglong,int>");
 }
 
