@@ -55,6 +55,7 @@ QHash<int, QByteArray> FileBrowserModel::roleNames() const
     roles[static_cast<int>(DataTypes::ColumnsRoles::TitleRole)] = "title";
     roles[static_cast<int>(DataTypes::ColumnsRoles::SecondaryTextRole)] = "secondaryText";
     roles[static_cast<int>(DataTypes::ColumnsRoles::ImageUrlRole)] = "imageUrl";
+    roles[static_cast<int>(DataTypes::ColumnsRoles::MultipleImageUrlsRole)] = "multipleImageUrls";
     roles[static_cast<int>(DataTypes::ColumnsRoles::DatabaseIdRole)] = "databaseId";
     roles[static_cast<int>(DataTypes::ColumnsRoles::ElementTypeRole)] = "dataType";
     roles[static_cast<int>(DataTypes::ColumnsRoles::ResourceRole)] = "url";
@@ -112,7 +113,7 @@ QVariant FileBrowserModel::data(const QModelIndex &index, int role) const
     case DataTypes::ColumnsRoles::IsPlayListRole:
     {
         KFileItem item = itemForIndex(index);
-        result = (item.currentMimeType().inherits(QStringLiteral("audio/x-mpegurl")));
+        result = (ElisaUtils::isPlayList(item.currentMimeType()));
         break;
     }
     case DataTypes::ColumnsRoles::ElementTypeRole:
@@ -130,7 +131,12 @@ QVariant FileBrowserModel::data(const QModelIndex &index, int role) const
                                                                   {DataTypes::TitleRole, item.name()},
                                                                   {DataTypes::ImageUrlRole, QUrl(QStringLiteral("image://icon/folder"))}});
         } else {
-            if (item.currentMimeType().inherits(QStringLiteral("audio/x-mpegurl"))) {
+            auto mimeType = item.currentMimeType();
+            if (ElisaUtils::isPlayList(mimeType)) {
+                result = QVariant::fromValue(DataTypes::MusicDataType{{DataTypes::ColumnsRoles::ResourceRole, item.url()},
+                                                                      {DataTypes::ColumnsRoles::ElementTypeRole, ElisaUtils::PlayList},
+                                                                      {DataTypes::TitleRole, item.name()},
+                                                                      {DataTypes::ImageUrlRole, QUrl(QStringLiteral("image://icon/audio-x-generic"))}});
             } else {
                 result = QVariant::fromValue(DataTypes::MusicDataType{{DataTypes::ColumnsRoles::ResourceRole, item.url()},
                                                                       {DataTypes::ColumnsRoles::ElementTypeRole, ElisaUtils::Track},
