@@ -41,7 +41,7 @@ public:
                              {i18nc("@title:inmenu", "Track Number"), i18nc("@title:inmenu", "Title")},
                              Qt::AscendingOrder,
                              {i18nc("@item:inmenu", "Ascending"), i18nc("@item:inmenu", "Descending"),
-                              i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
+                              i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A")},
                              ViewManager::SingleAlbum,
                              ViewManager::DiscHeaders}},
         {ElisaUtils::Genre, {{},
@@ -54,7 +54,7 @@ public:
                              {Qt::DisplayRole},
                              {i18nc("@title:inmenu", "Name")},
                              Qt::AscendingOrder,
-                             {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
+                             {i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A")},
                              QUrl{QStringLiteral("image://icon/view-media-artist")},
                              ViewManager::DelegateWithoutSecondaryText,
                              ViewManager::ViewHideRating}},
@@ -68,7 +68,7 @@ public:
                               {DataTypes::TitleRole, DataTypes::GenreRole, DataTypes::YearRole},
                               {i18nc("@title:inmenu", "Title"), i18nc("@title:inmenu", "Genre"), i18nc("@title:inmenu", "Year")},
                               Qt::AscendingOrder,
-                              {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
+                              {i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"), i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"), i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
                               QUrl{QStringLiteral("image://icon/media-default-album")},
                               ViewManager::DelegateWithSecondaryText,
                               ViewManager::ViewShowRating}},
@@ -82,10 +82,30 @@ public:
                                  {Qt::DisplayRole},
                                  {i18nc("@title:inmenu", "Name")},
                                  Qt::AscendingOrder,
-                                 {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
+                                 {i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A")},
                                  QUrl{QStringLiteral("image://icon/folder")},
                                  ViewManager::DelegateWithoutSecondaryText,
                                  ViewManager::ViewHideRating}},
+        {ElisaUtils::Track, {{},
+                             QUrl{QStringLiteral("image://icon/view-media-track")},
+                             ViewManager::TrackView,
+                             ViewManager::GenericDataModel,
+                             ElisaUtils::FilterByArtist,
+                             ElisaUtils::Track,
+                             DataTypes::TitleRole,
+                             {DataTypes::TitleRole, DataTypes::AlbumRole, DataTypes::ArtistRole,
+                             DataTypes::GenreRole, DataTypes::YearRole, DataTypes::DurationRole,
+                             DataTypes::ComposerRole, DataTypes::LyricistRole,
+                             DataTypes::FileModificationTime},
+                             {i18nc("@title:menu", "Title"), i18nc("@title:menu", "Album"), i18nc("@title:menu", "Artist"), i18nc("@title:menu", "Genre"),
+                             i18nc("@title:menu", "Year"), i18nc("@title:menu", "Duration"), i18nc("@title:menu", "Composer"), i18nc("@title:menu", "Lyricist"),
+                             i18nc("@title:menu", "Last Modified")},
+                             Qt::AscendingOrder,
+                             {i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"), i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"), i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"), i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"),
+                             i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First"), i18nc("@item:inmenu", "Shortest First"), i18nc("@item:inmenu", "Longest First"), i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"), i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"),
+                             i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
+                             ViewManager::MultipleAlbum,
+                             ViewManager::NoDiscHeaders}},
     };
 
     int mViewIndex = -1;
@@ -187,8 +207,17 @@ void ViewManager::openChildView(const DataTypes::MusicDataType &fullData)
     nextViewParameters.mDepth = d->mViewParametersStack.size() + 1;
     nextViewParameters.mDataFilter = fullData;
 
-    if (lastView.mFilterType == ElisaUtils::FilterByGenre) {
-        nextViewParameters.mFilterType = ElisaUtils::FilterByGenreAndArtist;
+    if (lastView.mFilterType == ElisaUtils::FilterByGenre || (lastView.mFilterType == ElisaUtils::FilterByGenreAndArtist && dataType != ElisaUtils::Album)) {
+        nextViewParameters.mFilterType =
+            dataType == ElisaUtils::Track && lastView.mDataType == ElisaUtils::Artist ? ElisaUtils::FilterByGenre : ElisaUtils::FilterByGenreAndArtist;
+    }
+
+    if (dataType == ElisaUtils::Artist) {
+        nextViewParameters.mSecondaryTitle = i18nc("@item:inlistbox Title of the view of all albums", "Albums");
+    } else if (dataType == ElisaUtils::Track) {
+        nextViewParameters.mSecondaryTitle = i18nc("@item:inlistbox Title of the view of all tracks", "Tracks");
+    } else if (dataType == ElisaUtils::Genre) {
+        nextViewParameters.mSecondaryTitle = i18nc("@item:inlistbox Title of the view of all artists", "Artists");
     }
 
     applyFilter(nextViewParameters, title, lastView);
@@ -198,6 +227,15 @@ void ViewManager::openChildView(const DataTypes::MusicDataType &fullData)
         return;
     }
 
+    // Don't recreate a view if we can go back to it
+    if (d->mViewParametersStack.size() >= 2) {
+        const auto &possiblyArtistView = d->mViewParametersStack.at(d->mViewParametersStack.size() - 2);
+        if (this->isSameView(nextViewParameters, possiblyArtistView)) {
+            goBack();
+            return;
+        }
+    }
+
     if (dataType == ElisaUtils::Album && nextViewParameters.mDataFilter[DataTypes::IsSingleDiscAlbumRole].toBool())
     {
         nextViewParameters.mAlbumViewStyle = NoDiscHeaders;
@@ -221,6 +259,17 @@ void ViewManager::openArtistView(const QString &artist)
                    {DataTypes::TitleRole, artist},});
 }
 
+void ViewManager::openTracksView(const QString &title)
+{
+    const auto &lastView = d->mViewParametersStack.back();
+
+    openChildView({
+        {DataTypes::ElementTypeRole, ElisaUtils::Track},
+        {DataTypes::TitleRole, title},
+        {DataTypes::ImageUrlRole, lastView.mDataFilter[DataTypes::ImageUrlRole]},
+    });
+}
+
 void ViewManager::openNowPlaying()
 {
     openView(0);
